@@ -1,5 +1,6 @@
 from .encrypt import encrypt as EncFunc
 from .decrypt import decrypt as DecFunc
+from time import sleep
 
 class chain:
     """
@@ -14,6 +15,10 @@ class chain:
     No return.
     """
     def __init__(self, level:int):
+        if level >= 13:
+            print("Your level is too high. It cause lag during encryption/decryption !")
+            print()
+            sleep(3)
         self.level = level
         
     def encrypt(self, text:str):
